@@ -10,17 +10,20 @@ except ImportError:
 # version
 from covsirphy.__version__ import __version__
 # util
-from covsirphy.util.plotting import line_plot
+from covsirphy.util.plotting import line_plot, line_plot_multiple
 from covsirphy.util.map import jpn_map
 from covsirphy.util.optimize import Optimizer
 from covsirphy.util.stopwatch import StopWatch
 from covsirphy.util.error import deprecate
 from covsirphy.util.error import SubsetNotFoundError, ScenarioNotFoundError, UnExecutedError
-from covsirphy.util.error import PCRIncorrectPreconditionError
+from covsirphy.util.error import PCRIncorrectPreconditionError, NotInteractiveError, UnExpectedValueError
 from covsirphy.util.file import save_dataframe
 from covsirphy.util.argument import find_args
+from covsirphy.util.term import Term, Word
+# visualization
+from covsirphy.visualization.vbase import VisualizeBase
+from covsirphy.visualization.colored_map import ColoredMap
 # cleaning
-from covsirphy.cleaning.term import Term, Word
 from covsirphy.cleaning.cbase import CleaningBase
 from covsirphy.cleaning.jhu_data import JHUData
 from covsirphy.cleaning.jhu_complement import JHUDataComplementHandler
@@ -77,13 +80,16 @@ __all__ = [
     "LinelistData", "PCRData", "JapanData", "JHUDataComplementHandler",
     "ModelBase", "SIR", "SIRD", "SIRF", "SIRFV", "SEWIRF",
     "Estimator", "Trend", "Optimizer",
-    "line_plot", "jpn_map", "StopWatch", "deprecate", "find_args",
+    "line_plot", "StopWatch", "deprecate", "find_args",
+    "line_plot_multiple",
     "save_dataframe",
     "PolicyMeasures",
     "SubsetNotFoundError", "ScenarioNotFoundError", "UnExecutedError",
-    "PCRIncorrectPreconditionError",
+    "PCRIncorrectPreconditionError", "NotInteractiveError",
+    "UnExpectedValueError",
+    "VisualizeBase", "ColoredMap",
     # Deprecated
-    "Population", "Word",
+    "Population", "Word", "jpn_map",
 ]
 
 # Show exceptions in better format if used from command line
