@@ -4,8 +4,11 @@
 import numpy as np
 import sklearn
 from covsirphy.util.error import UnExecutedError
-from covsirphy.cleaning.term import Term
+from covsirphy.util.argument import find_args
+from covsirphy.util.plotting import line_plot_multiple
+from covsirphy.util.term import Term
 from covsirphy.ode.mbase import ModelBase
+from covsirphy.phase.sr_change import ChangeFinder
 from covsirphy.phase.phase_unit import PhaseUnit
 from covsirphy.phase.phase_estimator import MPEstimator
 from covsirphy.phase.phase_series import PhaseSeries
@@ -17,10 +20,11 @@ class ParamTracker(Term):
 
     Args:
         record_df (pandas.DataFrame): records
-            Index:
+
+            Index
                 reset index
-            Columns:
-                - Date (pd.TimeStamp): Observation date
+            Columns
+                - Date (pandas.TimeStamp): Observation date
                 - Confirmed (int): the number of confirmed cases
                 - Infected (int): the number of currently infected cases
                 - Fatal (int): the number of fatal cases
@@ -39,12 +43,12 @@ class ParamTracker(Term):
     }
 
     def __init__(self, record_df, phase_series, area=None, tau=None):
-        self.record_df = self.ensure_dataframe(
+        self.record_df = self._ensure_dataframe(
             record_df, name="record_df", columns=self.SUB_COLUMNS)
-        self._series = self.ensure_instance(
+        self._series = self._ensure_instance(
             phase_series, PhaseSeries, name="phase_seres")
         self.area = area or ""
-        self.tau = self.ensure_tau(tau)
+        self.tau = self._ensure_tau(tau)
 
     def __len__(self):
         return len(self._series)
@@ -79,25 +83,25 @@ class ParamTracker(Term):
         """
         return self._series.unit(phase="last").model
 
-    def trend(self, force=True, show_figure=False, filename=None, **kwargs):
+    def trend(self, force=True, show_figure=False, **kwargs):
         """
         Split the records with trend analysis.
 
         Args:
             force (bool): if True, change points will be over-written
             show_figure (bool): if True, show the result as a figure
-            filename (str): filename of the figure, or None (show figure)
-            kwargs: keyword arguments of ChangeFinder()
+            kwargs: keyword arguments of covsirphy.ChangeFinder() and covsirphy.line_plot_multiple()
 
         Returns:
             covsirphy.PhaseSeries
         """
         sr_df = self.record_df.set_index(self.DATE).loc[:, [self.R, self.S]]
         if force or not self._series:
-            self._series.trend(sr_df=sr_df, **kwargs)
+            trend_kwargs = find_args(ChangeFinder, **kwargs)
+            self._series.trend(sr_df=sr_df, **trend_kwargs)
         if show_figure:
-            self._series.trend_show(
-                sr_df=sr_df, area=self.area, filename=filename)
+            show_kwargs = find_args(line_plot_multiple, **kwargs)
+            self._series.trend_show(sr_df=sr_df, area=self.area, **show_kwargs)
         return self._series
 
     def _ensure_phase_setting(self):
@@ -120,7 +124,7 @@ class ParamTracker(Term):
                 covsirphy.PhaseUnit: phase unit
         """
         self._ensure_phase_setting()
-        self.ensure_date(date)
+        self._ensure_date(date)
         phase_nest = [
             (self.num2str(i), unit) for (i, unit) in enumerate(self._series) if date in unit]
         try:
@@ -150,17 +154,27 @@ class ParamTracker(Term):
             date for base_date in base_dates
             for date in [self.yesterday(base_date), base_date, self.tomorrow(base_date)]]
 
+    def all_phases(self):
+        """
+        Return the names of all enabled phases.
+
+        Returns:
+            list[str]: the names of all enabled phases
+        """
+        return [self.num2str(num) for (num, unit) in enumerate(self._series) if unit]
+
     def disable(self, phases):
         """
         The phases will be disabled.
 
         Args:
-            phase (list[str] or None): phase names
+            phase (list[str] or None): phase names or None (all enabled phases)
 
         Returns:
             covsirphy.PhaseSeries
         """
-        phases = self.ensure_list(phases, candidates=None, name="phases")
+        phases = self._ensure_list(
+            phases or self.all_phases(), candidates=None, name="phases")
         for phase in phases:
             self._series.disable(phase)
         return self._series
@@ -170,12 +184,15 @@ class ParamTracker(Term):
         The phases will be enabled.
 
         Args:
-            phase (list[str] or None): phase names
+            phase (list[str] or None): phase names or None (all disabled phases)
 
         Returns:
             covsirphy.PhaseSeries
         """
-        phases = self.ensure_list(phases, candidates=None, name="phases")
+        all_dis_phases = [
+            self.num2str(num) for (num, unit) in enumerate(self._series) if not unit]
+        phases = self._ensure_list(
+            phases or all_dis_phases, candidates=None, name="phases")
         for phase in phases:
             self._series.enable(phase)
         return self._series
@@ -195,7 +212,7 @@ class ParamTracker(Term):
         Returns:
             covsirphy.PhaseSeries
 
-        Notes:
+        Note:
             - If the phases series has not been registered, new phase series will be created.
             - Either @end_date or @days must be specified.
             - If @end_date and @days are None, the end date will be the last date of the records.
@@ -206,7 +223,7 @@ class ParamTracker(Term):
             - kwargs: Default values are the parameter values of the last phase.
         """
         if end_date is not None:
-            self.ensure_date(end_date, name="end_date")
+            self._ensure_date(end_date, name="end_date")
         try:
             self._series.add(
                 end_date=end_date, days=days, population=population,
@@ -242,11 +259,10 @@ class ParamTracker(Term):
         Returns:
             covsirphy.PhaseSeries
         """
-        all_phases = [
-            self.num2str(num) for (num, unit) in enumerate(self._series) if unit]
+        all_phases = self.all_phases()
         if "last" in set(phases):
             phases = [ph for ph in phases if ph != "last"] + [all_phases[-1]]
-        self.ensure_list(phases, candidates=all_phases, name="phases")
+        self._ensure_list(phases, candidates=all_phases, name="phases")
         phases = sorted(list(set(phases)), key=self.str2num, reverse=True)
         for ph in phases:
             self._series.delete(ph)
@@ -268,8 +284,7 @@ class ParamTracker(Term):
         Returns:
             covsirphy.Scenario: self
         """
-        all_phases = [
-            self.num2str(num) for (num, unit) in enumerate(self._series) if unit]
+        all_phases = self.all_phases()
         if "last" in set(phases):
             phases.remove("last")
             phases = sorted(phases, key=self.str2num, reverse=False)
@@ -277,7 +292,7 @@ class ParamTracker(Term):
         else:
             phases = sorted(phases, key=self.str2num, reverse=False)
             last_phase = phases[-1]
-        self.ensure_list(phases, candidates=all_phases, name="phases")
+        self._ensure_list(phases, candidates=all_phases, name="phases")
         # Setting of the new phase
         start_date = self._series.unit(phases[0]).start_date
         end_date = self._series.unit(last_phase).end_date
@@ -331,7 +346,7 @@ class ParamTracker(Term):
                 list[str]: list of phase names
                 list[covsirphy.PhaseUnit]: list of phase units
 
-        Notes:
+        Note:
             If @phases is None, return the all past phases.
             If @phases is not None, intersection will be selected.
         """
@@ -343,15 +358,14 @@ class ParamTracker(Term):
             for (num, unit) in enumerate(self._series)
             if unit and unit <= last_date
         ]
-        past_phases, past_units = zip(*past_nest)
+        past_phases, _ = zip(*past_nest)
         # Select phases to use
-        selected_phases = self.ensure_list(
+        selected_phases = self._ensure_list(
             phases or past_phases, candidates=past_phases, name="phases")
-        final_phases = list(set(selected_phases) & set(past_phases))
+        final_phases = [
+            ph for ph in past_phases if ph in set(selected_phases)]
         # Convert phase names to phase units
-        selected_units = [self._series.unit(ph) for ph in selected_phases]
-        final_units = list(set(selected_units) & set(past_units))
-        return (final_phases, final_units)
+        return (final_phases, [self._series.unit(ph) for ph in final_phases])
 
     def future_phases(self):
         """
@@ -388,13 +402,13 @@ class ParamTracker(Term):
         Returns:
             tuple(int, covsirphy.PhaseSeries): tau value [min] and phase series
 
-        Notes:
+        Note:
             - If @phases is None, all past phase will be used.
             - Phases with estimated parameter values will be ignored.
             - In kwargs, tau value cannot be included.
         """
         self._ensure_phase_setting()
-        model = self.ensure_subclass(model, ModelBase, "model")
+        model = self._ensure_subclass(model, ModelBase, "model")
         units = [
             unit.set_id(phase=phase)
             for (phase, unit) in zip(*self.past_phases(phases=phases))
@@ -422,9 +436,9 @@ class ParamTracker(Term):
 
         Returns:
             pandas.DataFrame
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - Country (str): country/region name
                     - Province (str): province/prefecture/state name
@@ -447,11 +461,11 @@ class ParamTracker(Term):
         Returns:
             tuple(pandas.DataFrame, pandas.DataFrame):
                 - actual (pandas.DataFrame):
-                    Index: Date (pd.TimeStamp)
-                    Columns: variables defined by @variables
+                    Index Date (pd.TimeStamp)
+                    Columns variables defined by @variables
                 - simulated (pandas.DataFrame):
-                    Index: Date (pd.TimeStamp)
-                    Columns: variables defined by @variables
+                    Index Date (pd.TimeStamp)
+                    Columns variables defined by @variables
         """
         record_df = self.record_df.copy().set_index(self.DATE)
         simulated_df = self.simulate(y0_dict=y0_dict).set_index(self.DATE)
@@ -474,7 +488,7 @@ class ParamTracker(Term):
         Returns:
             float: score with the specified metrics
 
-        Notes:
+        Note:
             If @variables is None, ["Infected", "Fatal", "Recovered"] will be used.
             "Confirmed", "Infected", "Fatal" and "Recovered" can be used in @variables.
             If @phases is None, all phases will be used.
@@ -485,7 +499,7 @@ class ParamTracker(Term):
             raise ValueError(
                 f"@metrics must be selected from {metrics_str}, but {metrics} was applied.")
         variables = variables or [self.CI, self.F, self.R]
-        variables = self.ensure_list(
+        variables = self._ensure_list(
             variables, self.VALUE_COLUMNS, name="variables")
         # Disable the non-target phases
         all_phases, _ = self.past_phases(phases=None)
