@@ -7,6 +7,7 @@ from math import log10, floor
 import warnings
 import numpy as np
 import pandas as pd
+import ruptures as rpt
 from sklearn.model_selection import train_test_split
 from sklearn import linear_model
 from covsirphy.util.error import deprecate, ScenarioNotFoundError, UnExecutedError
@@ -32,11 +33,13 @@ class Scenario(DataHandler):
     def __init__(self, jhu_data, population_data, country, province=None, tau=None, auto_complement=True):
         super().__init__(
             jhu_data, population_data, country, province=province, auto_complement=auto_complement)
-        self.tau = self.ensure_tau(tau)
+        self.tau = self._ensure_tau(tau)
         self._update_range(first_date=None, last_date=None)
         # Linear regression modes for prediction of ODE parameters
         self._oxcgrt_data = None
         self._lm_dict = {}
+        # Default delay days
+        self.delay_days = self.jhu_data.recovery_period
 
     def __getitem__(self, key):
         """
@@ -98,21 +101,21 @@ class Scenario(DataHandler):
             last_date (str or None): the last date of the records
         """
         if first_date is not None:
-            self._first_date = self._ensure_date_in_range(first_date)
+            self._first_date = self.__ensure_date_in_range(first_date)
         if last_date is not None:
-            self._last_date = self._ensure_date_in_range(last_date)
+            self._last_date = self.__ensure_date_in_range(last_date)
         super().init_records()
         self._init_trackers()
 
-    def _ensure_date_in_range(self, date):
+    def __ensure_date_in_range(self, date):
         """
         Ensure that the date is in the range of (the first date, the last date).
 
         Args:
             date (str): date, like 01Jan2020
         """
-        self.ensure_date_order(self._first_date, date, name="date")
-        self.ensure_date_order(date, self._last_date, name="date")
+        self._ensure_date_order(self._first_date, date, name="date")
+        self._ensure_date_order(date, self._last_date, name="date")
         return date
 
     def _init_trackers(self):
@@ -168,7 +171,7 @@ class Scenario(DataHandler):
         Returns:
             covsirphy.Scenario: self
 
-        Notes:
+        Note:
             - If the phases series has not been registered, new phase series will be created.
             - Either @end_date or @days must be specified.
             - If @end_date and @days are None, the end date will be the last date of the records.
@@ -179,7 +182,7 @@ class Scenario(DataHandler):
             - kwargs: Default values are the parameter values of the last phase.
         """
         if end_date is not None:
-            self.ensure_date(end_date, name="end_date")
+            self._ensure_date(end_date, name="end_date")
         tracker = self._tracker(name)
         try:
             tracker.add(
@@ -204,7 +207,7 @@ class Scenario(DataHandler):
         Returns:
             covsirphy.Scenario: self
 
-        Notes:
+        Note:
             If un-registered scenario name was specified, new scenario will be created.
             Future phases will be always deleted.
         """
@@ -242,7 +245,7 @@ class Scenario(DataHandler):
         Returns:
             covsirphy.Scenario: self
 
-        Notes:
+        Note:
             If @phases is None, the phase series will be deleted.
             When @phase is '0th', disable 0th phase. 0th phase will not be deleted.
             If the last phase is included in @phases, the dates will be released from phases.
@@ -261,8 +264,8 @@ class Scenario(DataHandler):
         The phases will be disabled and removed from summary.
 
         Args:
-            phase (list[str] or None): phase names
-            name (str): name of phase series
+            phase (list[str] or None): phase names or None (all enabled phases)
+            name (str): scenario name
 
         Returns:
             covsirphy.Scenario: self
@@ -275,8 +278,8 @@ class Scenario(DataHandler):
         The phases will be enabled and appear in summary.
 
         Args:
-            phase (list[str] or None): phase names
-            name (str): name of phase series
+            phase (list[str] or None): phase names or None (all disabled phases)
+            name (str): scenario name
 
         Returns:
             covsirphy.Scenario: self
@@ -337,7 +340,7 @@ class Scenario(DataHandler):
             - if @name not None, as the same as PhaseSeries().summary()
             - if @name is None, index will be phase series name and phase name
 
-        Notes:
+        Note:
             If 'Main' was used as @name, main PhaseSeries will be used.
         """
         if name is None:
@@ -368,7 +371,7 @@ class Scenario(DataHandler):
             - if @name not None, as the same as PhaseSeries().summary()
             - if @name is None, index will be phase series name and phase name
 
-        Notes:
+        Note:
             If 'Main' was used as @name, main PhaseSeries will be used.
             If @columns is None, all columns will be shown.
         """
@@ -378,7 +381,7 @@ class Scenario(DataHandler):
             all_cols = [col for col in all_cols if col not in self.EST_COLS]
             all_cols += self.EST_COLS
         columns = columns or all_cols
-        self.ensure_list(columns, candidates=all_cols, name="columns")
+        self._ensure_list(columns, candidates=all_cols, name="columns")
         df = df.loc[:, columns]
         return df.dropna(how="all", axis=1).fillna(self.UNKNOWN)
 
@@ -391,7 +394,7 @@ class Scenario(DataHandler):
             name (str): phase series name
             show_figure (bool): if True, show the result as a figure
             filename (str): filename of the figure, or None (display)
-            kwargs: keyword arguments of ChangeFinder()
+            kwargs: keyword arguments of covsirphy.ChangeFinder() and covsirphy.line_plot_multiple()
 
         Returns:
             covsirphy.Scenario: self
@@ -415,6 +418,9 @@ class Scenario(DataHandler):
             pass
         # S-R trend analysis
         tracker = self._tracker(name)
+        if not self._interactive and filename is None:
+            show_figure = False
+        filename = None if self._interactive else filename
         self[name] = tracker.trend(
             force=force, show_figure=show_figure, filename=filename, **kwargs)
         # Disable 0th phase, if necessary
@@ -433,7 +439,7 @@ class Scenario(DataHandler):
             n_jobs (int): the number of parallel jobs or -1 (CPU count)
             kwargs: keyword arguments of model parameters and covsirphy.Estimator.run()
 
-        Notes:
+        Note:
             - If 'Main' was used as @name, main PhaseSeries will be used.
             - If @name phase was not registered, new PhaseSeries will be created.
             - If @phases is None, all past phase will be used.
@@ -472,7 +478,7 @@ class Scenario(DataHandler):
             name (str): phase series name
             kwargs: keyword arguments of covsirphy.Estimator.history()
 
-        Notes:
+        Note:
             If 'Main' was used as @name, main PhaseSeries will be used.
         """
         estimator = self.phase_estimator(phase=phase, name=name)
@@ -487,51 +493,51 @@ class Scenario(DataHandler):
             name (str): phase series name
             kwargs: keyword arguments of covsirphy.Estimator.accuracy()
 
-        Notes:
+        Note:
             If 'Main' was used as @name, main PhaseSeries will be used.
         """
         estimator = self.phase_estimator(phase=phase, name=name)
         estimator.accuracy(**kwargs)
 
-    def simulate(self, name="Main", y0_dict=None, show_figure=True, filename=None):
+    def simulate(self, variables=None, phases=None, name="Main", y0_dict=None, **kwargs):
         """
         Simulate ODE models with set/estimated parameter values and show it as a figure.
 
         Args:
+            variables (list[str] or None): variables to include, Infected/Fatal/Recovered when None
+            phases (list[str] or None): phases to shoe or None (all phases)
             name (str): phase series name. If 'Main', main PhaseSeries will be used
             y0_dict(dict[str, float] or None): dictionary of initial values of variables
-            show_figure (bool): if True, show the result as a figure
-            filename (str): filename of the figure, or None (show figure)
+            kwargs: the other keyword arguments of Scenario.line_plot()
 
         Returns:
             pandas.DataFrame
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - Country (str): country/region name
                     - Province (str): province/prefecture/state name
                     - Variables of the model and dataset (int): Confirmed etc.
         """
-        tracker = self._tracker(name)
+        tracker = copy.deepcopy(self._tracker(name))
+        # Select phases
+        if phases is not None:
+            tracker.disable(phases=None)
+            tracker.enable(phases=phases)
+        # Simulation
         try:
             sim_df = tracker.simulate(y0_dict=y0_dict)
         except UnExecutedError:
             raise UnExecutedError(
                 "Scenario.trend() or Scenario.add(), and Scenario.estimate(model)") from None
-        if not show_figure:
-            return sim_df
         # Show figure
         df = sim_df.set_index(self.DATE)
-        fig_cols_set = set(df.columns) & set(self.FIG_COLUMNS)
-        fig_cols = [col for col in self.FIG_COLUMNS if col in fig_cols_set]
-        line_plot(
-            df[fig_cols],
-            title=f"{self.area}: Simulated number of cases ({name} scenario)",
-            filename=filename,
-            y_integer=True,
-            v=tracker.change_dates()
-        )
+        fig_cols = self._ensure_list(
+            variables or [self.CI, self.F, self.R], candidates=df.columns.tolist(), name="variables")
+        title = f"{self.area}: Simulated number of cases ({name} scenario)"
+        self.line_plot(
+            df=df[fig_cols], title=title, y_integer=True, v=tracker.change_dates(), **kwargs)
         return sim_df
 
     def get(self, param, phase="last", name="Main"):
@@ -547,7 +553,7 @@ class Scenario(DataHandler):
         Returns:
             str or int or float
 
-        Notes:
+        Note:
             If 'Main' was used as @name, main PhaseSeries will be used.
         """
         df = self.summary(name=name)
@@ -612,7 +618,7 @@ class Scenario(DataHandler):
         Returns:
             pandas.DataFrame
 
-        Notes:
+        Note:
             If 'Main' was used as @name, main PhaseSeries will be used.
         """
         self._tracker(name)
@@ -651,9 +657,9 @@ class Scenario(DataHandler):
 
         Returns:
             pandas.DataFrame
-                Index:
+                Index
                     (int): scenario name
-                Columns:
+                Columns
                     - max(Infected): max value of Infected
                     - argmax(Infected): the date when Infected shows max value
                     - Confirmed({date}): Confirmed on the next date of the last phase
@@ -699,9 +705,9 @@ class Scenario(DataHandler):
 
         Returns:
             pandas.DataFrame:
-                Index:
+                Index
                     str: scenario name
-                Columns:
+                Columns
                     - max(Infected): max value of Infected
                     - argmax(Infected): the date when Infected shows max value
                     - Confirmed({date}): Confirmed on the next date of the last phase
@@ -730,8 +736,8 @@ class Scenario(DataHandler):
 
         Returns:
             pandas.DataFrame:
-                Index: Date (pandas.TimeStamp)
-                Columns:
+                Index Date (pandas.TimeStamp)
+                Columns
                     - Population (int)
                     - Rt (float)
                     - parameter values (float)
@@ -754,11 +760,12 @@ class Scenario(DataHandler):
         df[self.N] = df[self.N].astype(np.int64)
         return df
 
-    def _track(self, name, y0_dict=None):
+    def _track(self, phases=None, name="Main", y0_dict=None):
         """
         Show values of parameters and variables in one dataframe for the scenario.
 
         Args:
+            phases (list[str] or None): phases to shoe or None (all phases)
             name (str): phase series name
             y0_dict (dict or None): dictionary of initial values or None
                 - key (str): variable name
@@ -766,8 +773,8 @@ class Scenario(DataHandler):
 
         Returns:
             pandas.DataFrame:
-                Index: reset index
-                Columns:
+                Index reset index
+                Columns
                     - Date (pandas.TimeStamp)
                     - variables (int)
                     - Population (int)
@@ -775,27 +782,30 @@ class Scenario(DataHandler):
                     - parameter values (float)
                     - day parameter values (float)
         """
-        sim_df = self.simulate(name=name, y0_dict=y0_dict, show_figure=False)
+        sim_df = self.simulate(
+            phases=phases, name=name, y0_dict=y0_dict, show_figure=False)
         param_df = self._track_param(name=name)
         return pd.merge(
             sim_df, param_df, how="inner",
             left_on=self.DATE, right_index=True, sort=True
         )
 
-    def track(self, with_actual=True, y0_dict=None):
+    def track(self, phases=None, with_actual=True, y0_dict=None):
         """
         Show values of parameters and variables in one dataframe.
 
         Args:
+            phases (list[str] or None): phases to shoe or None (all phases)
             with_actual (bool): if True, show actual number of cases will included as "Actual" scenario
             y0_dict (dict or None): dictionary of initial values or None
                 - key (str): variable name
                 - value (float): initial value
 
         Returns:
-            pandas.DataFrame:
-                Index: reset index
-                Columns:
+            pandas.DataFrame: tracking records
+                Index
+                    reset index
+                Columns
                     - Scenario (str)
                     - Date (pandas.TimeStamp)
                     - variables (int)
@@ -807,21 +817,22 @@ class Scenario(DataHandler):
         dataframes = []
         append = dataframes.append
         for name in self._tracker_dict.keys():
-            df = self._track(name=name, y0_dict=y0_dict)
+            df = self._track(phases=phases, name=name, y0_dict=y0_dict)
             df.insert(0, self.SERIES, name)
             append(df)
         if with_actual:
-            df = self.records(show_figure=False)
+            df = self.record_df.copy()
             df.insert(0, self.SERIES, self.ACTUAL)
             append(df)
         return pd.concat(dataframes, axis=0, sort=False)
 
-    def _history(self, target, with_actual=True, y0_dict=None):
+    def _history(self, target, phases=None, with_actual=True, y0_dict=None):
         """
         Show the history of variables and parameter values to compare scenarios.
 
         Args:
             target (str): parameter or variable name to show (Rt, Infected etc.)
+            phases (list[str] or None): phases to shoe or None (all phases)
             with_actual (bool): if True and @target is a variable name, show actual number of cases
             y0_dict (dict or None): dictionary of initial values or None
                 - key (str): variable name
@@ -833,7 +844,8 @@ class Scenario(DataHandler):
         # Include actual data or not
         with_actual = with_actual and target in self.VALUE_COLUMNS
         # Get tracking data
-        df = self.track(with_actual=with_actual, y0_dict=y0_dict)
+        df = self.track(
+            phases=phases, with_actual=with_actual, y0_dict=y0_dict)
         if target not in df.columns:
             col_str = ", ".join(list(df.columns))
             raise KeyError(
@@ -842,26 +854,25 @@ class Scenario(DataHandler):
         return df.pivot_table(
             values=target, index=self.DATE, columns=self.SERIES, aggfunc="last")
 
-    def history(self, target, with_actual=True, y0_dict=None, show_figure=True, filename=None):
+    def history(self, target, phases=None, with_actual=True, y0_dict=None, **kwargs):
         """
         Show the history of variables and parameter values to compare scenarios.
 
         Args:
             target (str): parameter or variable name to show (Rt, Infected etc.)
+            phases (list[str] or None): phases to shoe or None (all phases)
             with_actual (bool): if True and @target is a variable name, show actual number of cases
             y0_dict (dict or None): dictionary of initial values or None
                 - key (str): variable name
                 - value (float): initial value
-            show_figure (bool): If True, show the result as a figure
-            filename (str): filename of the figure, or None (show figure)
+            kwargs: the other keyword arguments of Scenario.line_plot()
 
         Returns:
             pandas.DataFrame
         """
         df = self._history(
-            target=target, with_actual=with_actual, y0_dict=y0_dict)
-        if not show_figure:
-            return df
+            target=target, phases=phases, with_actual=with_actual, y0_dict=y0_dict)
+        df = df.dropna()
         if target == self.RT:
             ylabel = self.RT_FULL
         elif target in self.VALUE_COLUMNS:
@@ -870,16 +881,12 @@ class Scenario(DataHandler):
             ylabel = target
         title = f"{self.area}: {ylabel} over time"
         tracker = self._tracker(self.MAIN)
-        line_plot(
-            df, title, ylabel=ylabel,
-            h=1.0 if target == self.RT else None,
-            v=tracker.change_dates(),
-            math_scale=False,
-            filename=filename
-        )
+        self.line_plot(
+            df=df, title=title, ylabel=ylabel, v=tracker.change_dates(), math_scale=False,
+            h=1.0 if target == self.RT else None, **kwargs)
         return df
 
-    def history_rate(self, params=None, name="Main", show_figure=True, filename=None):
+    def history_rate(self, params=None, name="Main", **kwargs):
         """
         Show change rates of parameter values in one figure.
         We can find the parameters which increased/decreased significantly.
@@ -887,8 +894,7 @@ class Scenario(DataHandler):
         Args:
             params (list[str] or None): parameters to show
             name (str): phase series name
-            show_figure (bool): If True, show the result as a figure
-            filename (str): filename of the figure, or None (show figure)
+            kwargs: the other keyword arguments of Scenario.line_plot()
 
         Returns:
             pandas.DataFrame
@@ -902,15 +908,14 @@ class Scenario(DataHandler):
                     f"@params must be a list of parameters, but {params} were applied.")
             cols = list(set(cols) & set(params)) or cols
         df = df.loc[:, cols] / df.loc[df.index[0], cols]
-        if show_figure:
-            f_date = df.index[0].strftime(self.DATE_FORMAT)
-            title = f"{self.area}: {model.NAME} parameter change rates over time (1.0 on {f_date})"
-            ylabel = f"Value per that on {f_date}"
-            title = f"{self.area}: {ylabel} over time"
-            tracker = self._tracker(self.MAIN)
-            line_plot(
-                df, title, ylabel=ylabel, v=tracker.change_dates(),
-                math_scale=False, filename=filename)
+        # Show figure
+        f_date = df.index[0].strftime(self.DATE_FORMAT)
+        title = f"{self.area}: {model.NAME} parameter change rates over time (1.0 on {f_date})"
+        ylabel = f"Value per that on {f_date}"
+        title = f"{self.area}: {ylabel} over time"
+        tracker = self._tracker(self.MAIN)
+        self.line_plot(
+            df=df, title=title, ylabel=ylabel, v=tracker.change_dates(), math_scale=False, **kwargs)
         return df
 
     def retrospective(self, beginning_date, model, control="Main", target="Target", **kwargs):
@@ -926,7 +931,7 @@ class Scenario(DataHandler):
             target (str): scenario name of target
             kwargs: keyword argument of parameter values and Estimator.run()
 
-        Notes:
+        Note:
             When parameter values are not specified,
             actual values of the last date before the beginning date will be used.
         """
@@ -966,7 +971,7 @@ class Scenario(DataHandler):
         Returns:
             float: score with the specified metrics
 
-        Notes:
+        Note:
             If @variables is None, ["Infected", "Fatal", "Recovered"] will be used.
             "Confirmed", "Infected", "Fatal" and "Recovered" can be used in @variables.
             If @phases is None, all phases will be used.
@@ -977,7 +982,7 @@ class Scenario(DataHandler):
             if phases is not None:
                 raise ValueError(
                     "@phases and @past_days cannot be specified at the same time.")
-            past_days = self.ensure_natural_int(past_days, name="past_days")
+            past_days = self._ensure_natural_int(past_days, name="past_days")
             # Separate a phase, if possible
             beginning_date = self.date_change(
                 self._last_date, days=0 - past_days)
@@ -994,7 +999,83 @@ class Scenario(DataHandler):
         return tracker.score(
             metrics=metrics, variables=variables, phases=phases, y0_dict=y0_dict)
 
-    def _fit_create_data(self, oxcgrt_data, model, name):
+    def estimate_delay(self, oxcgrt_data, indicator="Stringency_index",
+                       target="Infected", value_range=(7, 35)):
+        """
+        Estimate the average delay (in days) between a policy measure taken
+        and the moment of change in for the given target value, for example
+        `Infected`.The change over time is calculated with penalized change
+        point analysis. More information about the method of change point
+        detection can be found on:
+        https://ctruong.perso.math.cnrs.fr/ruptures-docs/build/html/detection/pelt.html.
+
+        Args:
+            oxcgrt_data (covsirphy.OxCGRTData): OxCGRT dataset
+            indicator (str): column variable from the OxCGRT dataset
+            target (str): one of the target columns to detect changes in,
+                options are ["Infected", "Confirmed", "Fatal", "Recovered"].
+            value_range (int, int): tuple, giving the minimum and maximum
+            range to search for change over time. It is assumed that when a
+            policy measure is taken, change will occur after at least 7 days
+            and before 35 days (=default).
+
+        Returns:
+            tuple(int, pandas.DataFrame):
+                - int: the estimated number of days of delay for a given country.
+                - pandas.DataFrame: dataframe of target, indicator and calculated periods of change (in days).
+
+        Note:
+            Average recovered period of JHU dataset will be used as returned value
+            when the estimated value was not in value_range.
+            Very long periods (outside of 99% quantile) are taken out.
+        """
+        warnings.simplefilter("ignore", category=RuntimeWarning)
+        records = self.record_df.set_index(self.DATE)
+        default_df = pd.DataFrame()
+        oxcgrt_df = oxcgrt_data.subset(
+            country=self.country).set_index(self.DATE)
+        records[indicator] = oxcgrt_df.loc[:, indicator]
+        records = records.reset_index()
+        df = records.pivot_table(index=target, values=indicator)
+        df_run = df.copy()
+        # Convert index to serial numbers
+        serial_df = pd.DataFrame(np.arange(1, df_run.index.max() + 1, 1))
+        serial_df.index += 1
+        df_run = df_run.join(serial_df, how="outer")
+        series = df_run.reset_index(drop=True).iloc[:, 0].dropna()
+        # Convert index values to Susceptible values
+        reset_series = series.reset_index(drop=True)
+        reset_series.index += 1
+        # Detection with Ruptures
+        algorithm = rpt.Pelt(model="rbf", jump=1, min_size=value_range[0])
+        try:
+            results = algorithm.fit_predict(series.values, pen=0.5)
+        except ValueError:
+            warnings.warn(
+                "Delay days could not be estimated for {self.country} and delay set to default: {self.delay_days} [days]",
+                UserWarning, stacklevel=1
+            )
+            return self.jhu_data.recovery_period, default_df
+        results_df = reset_series[results].reset_index()
+        results_df = results_df.interpolate(
+            method="linear").dropna().astype(np.float64)
+        # Convert new_confirmed values to dates
+        df = pd.merge_asof(
+            results_df.sort_values(indicator),
+            df.astype(np.float64).reset_index().sort_values(indicator),
+            on=indicator, direction="nearest"
+        )
+        # Calculate number of days between the periods
+        df["Period Length"] = df["index"].sort_values(ignore_index=True).diff()
+        # Filter out very long periods
+        sel1 = df["Period Length"] < df["Period Length"].quantile(0.99)
+        sel2 = (df["Period Length"] < value_range[1])
+        df_filtered = df.loc[sel1 & sel2]
+        delay_days = self.delay_days if df_filtered.empty else int(
+            df_filtered["Period Length"].mean())
+        return delay_days, df[[target, indicator, "Period Length"]]
+
+    def _fit_create_data(self, oxcgrt_data, model, name, delay):
         """
         Create train/test dataset for Elastic Net regression,
         assuming that OxCGRT scores will impact on ODE parameter values with delay (recovery period).
@@ -1003,6 +1084,7 @@ class Scenario(DataHandler):
             oxcgrt_data (covsirphy.OxCGRTData): OxCGRT dataset
             model (covsirphy.ModelBase): ODE model
             name (str): scenario name
+            delay (int): number of days of delay between policy measure and effect on number of confirmed cases
 
         Returns:
             tuple(pandas.DataFrame):
@@ -1016,7 +1098,6 @@ class Scenario(DataHandler):
         oxcgrt_df = oxcgrt_data.subset(
             country=self.country).set_index(self.DATE)[OxCGRTData.OXCGRT_VARS_INDICATORS]
         # Apply delay on OxCGRT data
-        delay = self.jhu_data.recovery_period
         oxcgrt_df.index += timedelta(days=delay)
         # Create training/test dataset
         df = param_df.join(oxcgrt_df, how="inner")
@@ -1032,7 +1113,7 @@ class Scenario(DataHandler):
         X_target = oxcgrt_df.loc[dates]
         return (X, y, X_target)
 
-    def fit(self, oxcgrt_data, name="Main", test_size=0.2, seed=0):
+    def fit(self, oxcgrt_data, name="Main", test_size=0.2, seed=0, delay=None):
         """
         Learn the relationship of ODE parameter values and delayed OxCGRT scores using Elastic Net regression,
         assuming that OxCGRT scores will impact on ODE parameter values with delay (=recovery period).
@@ -1042,6 +1123,8 @@ class Scenario(DataHandler):
             name (str): scenario name
             test_size (float): proportion of the test dataset of Elastic Net regression
             seed (int): random seed when spliting the dataset to train/test data
+            delay (int): number of days of delay between policy measure and effect
+            on number of confirmed cases.
 
         Returns:
             dict(str, object):
@@ -1049,13 +1132,15 @@ class Scenario(DataHandler):
                 - l1_ratio (float): l1_ratio value used in Elastic Net regression
                 - score_train (float): determination coefficient of train dataset
                 - score_test (float): determination coefficient of test dataset
-                - intercept (pandas.DataFrame): intercept values (Index: ODE parameters, Columns: OxCGRT indicators)
+                - intercept (pandas.DataFrame): intercept values (Index ODE parameters, Columns OxCGRT indicators)
+                - delay (int): number of days of delay between policy measure and effect
+                  on number of confirmed cases.
 
         Raises:
-            UnExecutedError: Scenario.estimate() or Scenario.add() were not performed
+            covsirphy.UnExecutedError: Scenario.estimate() or Scenario.add() were not performed
         """
         # Register OxCGRT data
-        self._oxcgrt_data = self.ensure_instance(
+        self._oxcgrt_data = self._ensure_instance(
             oxcgrt_data, OxCGRTData, name="oxcgrt_data")
         # ODE model
         model = self._tracker(name).last_model
@@ -1063,9 +1148,13 @@ class Scenario(DataHandler):
             raise UnExecutedError(
                 "Scenario.estimate() or Scenario.add()",
                 message=f", specifying @model (covsirphy.SIRF etc.) and @name='{name}'.")
+        # Set delay effect
+        if delay is None:
+            delay, _ = self.estimate_delay(oxcgrt_data)
+        self.delay_days = delay
         # Create training/test dataset
         X, y, *_ = self._fit_create_data(
-            oxcgrt_data=oxcgrt_data, model=model, name=name)
+            oxcgrt_data=oxcgrt_data, model=model, name=name, delay=delay)
         X_train, X_test, y_train, y_test = train_test_split(
             X, y, test_size=test_size, random_state=seed)
         # Optimize parameters of Elastic Net regression
@@ -1087,6 +1176,7 @@ class Scenario(DataHandler):
                 "score_test": lm.score(X_test, y_test),
                 "intercept": pd.DataFrame(
                     lm.coef_, index=y_train.columns, columns=X_train.columns),
+                "delay": delay
             }
         )
         return info_dict
@@ -1104,7 +1194,7 @@ class Scenario(DataHandler):
             covsirphy.Scenario: self
 
         Raises:
-            UnExecutedError: Scenario.fit() was not performed
+            covsirphy.UnExecutedError: Scenario.fit() was not performed
         """
         # Arguments
         if name not in self._lm_dict:
@@ -1115,7 +1205,7 @@ class Scenario(DataHandler):
         self.clear(name=name)
         # Create X dataset of the target dates
         *_, X_target = self._fit_create_data(
-            oxcgrt_data=self._oxcgrt_data, model=model, name=name)
+            oxcgrt_data=self._oxcgrt_data, model=model, name=name, delay=self.delay_days)
         # -> end_date/parameter values
         df = pd.DataFrame(
             lm.predict(X_target), index=X_target.index, columns=model.PARAMETERS)
@@ -1145,7 +1235,7 @@ class Scenario(DataHandler):
             covsirphy.Scenario: self
 
         Raises:
-            UnExecutedError: Scenario.estimate() or Scenario.add() were not performed
+            covsirphy.UnExecutedError: Scenario.estimate() or Scenario.add() were not performed
         """
         self.fit(oxcgrt_data=oxcgrt_data, name=name, **kwargs)
         self.predict(name=name)
