@@ -16,7 +16,7 @@ class CountryData(CleaningBase):
         country (str): country name
         province (str or None): province name
 
-    Returns:
+    Note:
         If province name will be set in CountryData.set_variables(), @province will be ignored.
     """
 
@@ -71,9 +71,9 @@ class CountryData(CleaningBase):
 
         Returns:
             pandas.DataFrame:
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - Country (pandas.Category): country/region name
                     - Province (pandas.Category): province/prefecture/state name
@@ -91,7 +91,7 @@ class CountryData(CleaningBase):
         expected_cols = [
             self.DATE, self.C, self.F, self.R
         ]
-        self.ensure_dataframe(df, name="the raw data", columns=expected_cols)
+        self._ensure_dataframe(df, name="the raw data", columns=expected_cols)
         # Remove empty rows
         df = df.dropna(subset=[self.DATE])
         # Add province column
@@ -101,6 +101,8 @@ class CountryData(CleaningBase):
             df[self.PROVINCE] = self._province or self.UNKNOWN
         # Values
         v_cols = [self.C, self.F, self.R]
+        for col in v_cols:
+            df[col] = pd.to_numeric(df[col], errors="coerce")
         df[v_cols] = df[v_cols].fillna(0).astype(np.int64)
         df[self.CI] = df[self.C] - df[self.F] - df[self.R]
         # Groupby date and province
@@ -120,9 +122,9 @@ class CountryData(CleaningBase):
 
         Returns:
             pandas.DataFrame:
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - Country (pandas.Category): country/region name
                     - Province (pandas.Category): province/prefecture/sstate name
@@ -131,7 +133,8 @@ class CountryData(CleaningBase):
                     - Fatal (int): the number of fatal cases
                     - Recovered (int): the number of recovered cases
         """
-        self._cleaned_df = self._cleaning()
+        if self._cleaned_df.empty:
+            self._cleaned_df = self._cleaning()
         return self._cleaned_df
 
     def total(self):
@@ -141,9 +144,9 @@ class CountryData(CleaningBase):
         Returns:
             pandas.DataFrame: group-by Date, sum of the values
 
-                Index:
+                Index
                     Date (pd.TimeStamp): Observation date
-                Columns:
+                Columns
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
                     - Fatal (int): the number of fatal cases
@@ -177,3 +180,26 @@ class CountryData(CleaningBase):
             list[str]: list of country names
         """
         return [self._country]
+
+    def register_total(self):
+        """
+        Register total value of all provinces as country level data.
+
+        Returns:
+            covsirphy.CountryData: self
+
+        Note:
+            If country level data was registered, this will be overwritten.
+        """
+        # Calculate total values at province level
+        clean_df = self.cleaned()
+        clean_df = clean_df.loc[clean_df[self.PROVINCE] != self.UNKNOWN]
+        total_df = clean_df.groupby(self.DATE).sum().reset_index()
+        total_df[self.COUNTRY] = self._country
+        total_df[self.PROVINCE] = self.UNKNOWN
+        # Add/overwrite country level data
+        df = clean_df.loc[clean_df[self.PROVINCE] != self.UNKNOWN]
+        df = pd.concat([df, total_df], ignore_index=True, sort=True)
+        df[self.STR_COLUMNS] = df[self.STR_COLUMNS].astype("category")
+        self._cleaned_df = df.loc[:, self.COLUMNS]
+        return self
