@@ -16,7 +16,7 @@ class JapanData(CountryData):
         force (bool): if True, always download the dataset from the server
         verbose (int): level of verbosity
 
-    Notes:
+    Note:
         Columns of JapanData.cleaned():
             - Date (pandas.TimeStamp): date
             - Country (pandas.Category): 'Japan'
@@ -190,15 +190,16 @@ class JapanData(CountryData):
 
         Returns:
             pandas.DataFrame: (cleaned or raw) dataset
-                Index: reset index
-                Columns: for cleaned dataset,
+                Index
+                    reset index
+                Columns for cleaned dataset,
                     - Prefecture (pandas.Category)
                     - Admin_Capital (pandas.Category)
                     - Admin_Region (pandas.Category)
                     - Admin_Num (int)
                     - Area_Habitable (int)
                     - Area_Total (int)
-                    - Clinic_bed_Care (int) 
+                    - Clinic_bed_Care (int)
                     - Clinic_bed_Total (int)
                     - Hospital_bed_Care (int)
                     - Hospital_bed_Specific (int)
