@@ -32,7 +32,7 @@ class JHUData(CleaningBase):
 
     @recovery_period.setter
     def recovery_period(self, value):
-        self._recovery_period = self.ensure_natural_int(value)
+        self._recovery_period = self._ensure_natural_int(value)
 
     def cleaned(self, **kwargs):
         """
@@ -43,9 +43,9 @@ class JHUData(CleaningBase):
 
         Returns:
             pandas.DataFrame
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - Country (pandas.Category): country/region name
                     - Province (pandas.Category): province/prefecture/state name
@@ -54,7 +54,7 @@ class JHUData(CleaningBase):
                     - Fatal (int): the number of fatal cases
                     - Recovered (int): the number of recovered cases
 
-        Notes:
+        Note:
             Cleaning method is defined by self._cleaning() method.
         """
         if "population" in kwargs.keys():
@@ -69,9 +69,9 @@ class JHUData(CleaningBase):
 
         Returns:
             pandas.DataFrame
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - ISO3 (str): ISO3 code
                     - Country (pandas.Category): country/region name
@@ -96,7 +96,7 @@ class JHUData(CleaningBase):
         expected_cols = [
             self.DATE, self.ISO3, self.COUNTRY, self.PROVINCE, self.C, self.F, self.R
         ]
-        self.ensure_dataframe(df, name="the raw data", columns=expected_cols)
+        self._ensure_dataframe(df, name="the raw data", columns=expected_cols)
         # Datetime columns
         df[self.DATE] = pd.to_datetime(df[self.DATE])
         # Country
@@ -119,6 +119,17 @@ class JHUData(CleaningBase):
         df[self.CI] = df[self.C] - df[self.F] - df[self.R]
         df[self.VALUE_COLUMNS] = df[self.VALUE_COLUMNS].astype(np.int64)
         df = df.loc[:, [self.ISO3, *self.COLUMNS]].reset_index(drop=True)
+        # As country level data in China, use the total values of provinces
+        p_chn_df = df.loc[
+            (df[self.COUNTRY] == "China") & (df[self.PROVINCE] != self.UNKNOWN)]
+        p_chn_df = p_chn_df.groupby(self.DATE).sum().reset_index()
+        p_chn_df.insert(0, self.COUNTRY, "China")
+        p_chn_df.insert(0, self.PROVINCE, self.UNKNOWN)
+        p_chn_df[self.ISO3] = self.country_to_iso3(
+            country="China", check_data=False)
+        without_c_chn_df = df.loc[
+            (df[self.COUNTRY] != "China") | (df[self.PROVINCE] != self.UNKNOWN)]
+        df = pd.concat([without_c_chn_df, p_chn_df], ignore_index=True)
         # Update data types to reduce memory
         df[self.AREA_ABBR_COLS] = df[self.AREA_ABBR_COLS].astype("category")
         return df
@@ -133,10 +144,10 @@ class JHUData(CleaningBase):
         Returns:
             covsirphy.JHUData: self
 
-        Notes:
+        Note:
             Citation of the country data will be added to 'JHUData.citation' description.
         """
-        self.ensure_instance(country_data, CountryData, name="country_data")
+        self._ensure_instance(country_data, CountryData, name="country_data")
         # Read new dataset
         country = country_data.country
         new = country_data.cleaned().loc[:, self.COLUMNS]
@@ -165,9 +176,9 @@ class JHUData(CleaningBase):
 
         Returns:
             pandas.DataFrame
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
@@ -186,8 +197,9 @@ class JHUData(CleaningBase):
 
         Args:
             subset_df (pandas.DataFrame)
-                Index: reset index
-                Columns:
+                Index
+                    reset index
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
@@ -197,9 +209,9 @@ class JHUData(CleaningBase):
 
         Returns:
             pandas.DataFrame
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
@@ -207,7 +219,7 @@ class JHUData(CleaningBase):
                     - Recovered (int): the number of recovered cases
                     - Susceptible (int): the number of susceptible cases, if calculated
 
-        Notes:
+        Note:
             If @population is not None, the number of susceptible cases will be calculated.
         """
         if population is None:
@@ -228,9 +240,9 @@ class JHUData(CleaningBase):
 
         Returns:
             pandas.DataFrame
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
@@ -238,7 +250,7 @@ class JHUData(CleaningBase):
                     - Recovered (int): the number of recovered cases (> 0)
                     - Susceptible (int): the number of susceptible cases, if calculated
 
-        Notes:
+        Note:
             If @population is not None, the number of susceptible cases will be calculated.
         """
         country_alias = self.ensure_country_name(country)
@@ -273,17 +285,17 @@ class JHUData(CleaningBase):
 
         Returns:
             pandas.DataFrame
-                Index:
+                Index
                     Date (pd.TimeStamp): Observation date
-                Columns:
+                Columns
                     - Recovered (int): the number of recovered cases (> 0)
                     - Susceptible (int): the number of susceptible cases
 
-        Notes:
+        Note:
             @population must be specified.
             Records with Recovered > 0 will be used.
         """
-        population = self.ensure_population(population)
+        population = self._ensure_population(population)
         subset_df = self.subset(
             country=country, province=province,
             start_date=start_date, end_date=end_date, population=population)
@@ -301,7 +313,7 @@ class JHUData(CleaningBase):
             covsirphy.JHUData: JHU-style dataset
         """
         instance = cls(filename=None)
-        instance._cleaned_df = cls.ensure_dataframe(
+        instance._cleaned_df = cls._ensure_dataframe(
             dataframe, name="dataframe", columns=cls.COLUMNS)
         return instance
 
@@ -312,9 +324,9 @@ class JHUData(CleaningBase):
         Returns:
             pandas.DataFrame: group-by Date, sum of the values
 
-                Index:
-                    Date (pd.TimeStamp): Observation date
-                Columns:
+                Index
+                    Date (pandas.TimeStamp): Observation date
+                Columns
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
                     - Fatal (int): the number of fatal cases
@@ -331,6 +343,10 @@ class JHUData(CleaningBase):
         df[r_cols[0]] = df[self.F] / total_series
         df[r_cols[1]] = df[self.R] / total_series
         df[r_cols[2]] = df[self.F] / (df[self.F] + df[self.R])
+        # Set the final date of the records
+        raw_df = self._raw.rename({"ObservationDate": self.DATE}, axis=1)
+        final_date = pd.to_datetime(raw_df[self.DATE]).dt.date.max()
+        df = df.loc[df.index.date <= final_date]
         return df.loc[:, [*self.VALUE_COLUMNS, *r_cols]]
 
     def countries(self, complement=True, **kwargs):
@@ -367,7 +383,7 @@ class JHUData(CleaningBase):
         Returns:
             int: closing period [days]
 
-        Notes:
+        Note:
             If no records we can use for calculation were registered, 12 [days] will be applied.
         """
         # Get cleaned dataset at country level
@@ -400,32 +416,47 @@ class JHUData(CleaningBase):
         Returns:
             int: recovery period [days]
 
-        Notes:
+        Note:
             If no records we can use for calculation were registered, 17 [days] will be applied.
         """
+        default = 17
         # Get valid data for calculation
         df = self._cleaned_df.copy()
         df = df.loc[df[self.PROVINCE] == self.UNKNOWN]
         df = df.groupby(self.COUNTRY).filter(lambda x: x[self.R].sum() != 0)
-        # If no records were found 17 days will be returned
+        # If no records were found the default value will be returned
         if df.empty:
-            return 17
+            return default
         # Calculate median value of recovery period in all countries with valid data
         periods = [
             self._calculate_recovery_period_country(df, country)
             for country in df[self.COUNTRY].unique()
         ]
-        return int(pd.Series(periods).median())
+        valid_periods = list(filter(lambda x: x >= 0, periods))
+        if not valid_periods:
+            return default
+        try:
+            return int(pd.Series(valid_periods).median())
+        except ValueError:
+            return default
 
-    def _calculate_recovery_period_country(self, valid_df, country):
+    def _calculate_recovery_period_country(self, valid_df, country, upper_limit_days=90,
+                                           lower_limit_days=7, upper_percentage=0.5, lower_percentage=0.5):
         """
         Calculate mode value of recovery period in the country.
         If many mode values were found, mean value of mode values will be returned.
 
         Args:
             valid_df (pandas.DataFrame):
-                - Index: reset_index
-                - Columns: Date, Confirmed, Recovered, Fatal
+                Index
+                    reset_index
+                Columns
+                    Date, Confirmed, Recovered, Fatal
+            country(str): country name or ISO3 code
+            upper_limit_days (int): maximum number of valid partial recovery periods [days]
+            lower_limit_days (int): minimum number of valid partial recovery periods [days]
+            upper_percentage (float): fraction of partial recovery periods with value greater than upper_limit_days
+            lower_percentage (float): fraction of partial recovery periods with value less than lower_limit_days
 
         Returns:
             int: mode value of recovery period [days]
@@ -445,11 +476,15 @@ class JHUData(CleaningBase):
         df = df.interpolate(limit_area="inside").dropna().astype(np.int64)
         df["Elapsed"] = df[self.R] - df["diff"]
         df = df.loc[df["Elapsed"] > 0]
+        # Check partial recovery periods
+        per_up = (df["Elapsed"] > upper_limit_days).sum() / len(df)
+        per_lw = (df["Elapsed"] < lower_limit_days).sum() / len(df)
+        if per_up >= upper_percentage or per_lw >= lower_percentage:
+            return -1
         return df["Elapsed"].mode().mean()
 
     def subset_complement(self, country, province=None,
-                          start_date=None, end_date=None, population=None,
-                          interval=2, max_ignored=100, max_ending_unupdated=14):
+                          start_date=None, end_date=None, population=None, **kwargs):
         """
         Return the subset of dataset and complement recovered data, if necessary.
         Records with Recovered > 0 will be selected.
@@ -460,31 +495,25 @@ class JHUData(CleaningBase):
             start_date(str or None): start date, like 22Jan2020
             end_date(str or None): end date, like 01Feb2020
             population(int or None): population value
-            interval (int): expected update interval of the number of recovered cases [days]
-            max_ignored (int): Max number of recovered cases to be ignored [cases]
-            max_ending_unupdated (int) : Max number of days to apply full complement,
-                 where ending recovered cases are not updated [days]
+            kwargs: keyword arguments of JHUDataComplementHandler(), control factors of complement
 
         Returns:
-            tuple(pandas.DataFrame, str/bool):
+            tuple(pandas.DataFrame, str or bool):
                 pandas.DataFrame:
-                    Index:
+                    Index
                         reset index
-                    Columns:
+                    Columns
                         - Date(pd.TimeStamp): Observation date
                         - Confirmed(int): the number of confirmed cases
                         - Infected(int): the number of currently infected cases
                         - Fatal(int): the number of fatal cases
                         - Recovered (int): the number of recovered cases ( > 0)
                         - Susceptible(int): the number of susceptible cases, if calculated
-                str/bool: kind of complement or False
+                str or bool: kind of complement or False
 
-        Notes:
+        Note:
             If @population is not None, the number of susceptible cases will be calculated.
         """
-        # Arguments
-        interval = self.ensure_natural_int(interval, name="interval")
-        max_ignored = self.ensure_natural_int(max_ignored, name="max_ignored")
         # Subset with area, start/end date and calculate Susceptible
         country_alias = self.ensure_country_name(country)
         subset_df = self._subset(
@@ -496,12 +525,8 @@ class JHUData(CleaningBase):
         # Complement, if necessary
         self._recovery_period = self._recovery_period or self.calculate_recovery_period()
         handler = JHUDataComplementHandler(
-            recovery_period=self._recovery_period,
-            interval=interval,
-            max_ignored=max_ignored,
-            max_ending_unupdated=max_ending_unupdated,
-        )
-        df, status = handler.run(subset_df)
+            recovery_period=self._recovery_period, **kwargs)
+        df, status, _ = handler.run(subset_df)
         # Calculate Susceptible
         df = self._calculate_susceptible(df, population)
         # Kind of complement or False
@@ -528,19 +553,21 @@ class JHUData(CleaningBase):
         Returns:
             tuple(pandas.DataFrame, bool):
                 pandas.DataFrame:
-                    Index: reset index
-                    Columns:
+
+                    Index
+                        reset index
+                    Columns
                         - Date(pd.TimeStamp): Observation date
                         - Confirmed(int): the number of confirmed cases
                         - Infected(int): the number of currently infected cases
                         - Fatal(int): the number of fatal cases
                         - Recovered (int): the number of recovered cases ( > 0)
                         - Susceptible(int): the number of susceptible cases, if calculated
-                str/bool: kind of complement or False
+                str or bool: kind of complement or False
 
-        Notes:
-            If @ population is not None, the number of susceptible cases will be calculated.
-            If necessary and @auto_complement is True, complement recovered data.
+        Note:
+            - If @ population is not None, the number of susceptible cases will be calculated.
+            - If necessary and @auto_complement is True, complement recovered data.
         """
         country_alias = self.ensure_country_name(country)
         subset_arg_dict = {
@@ -558,3 +585,100 @@ class JHUData(CleaningBase):
             raise SubsetNotFoundError(
                 country=country, country_alias=country_alias, province=province,
                 start_date=start_date, end_date=end_date, message="with 'Recovered > 0'") from None
+
+    def show_complement(self, country=None, province=None,
+                        start_date=None, end_date=None, **kwargs):
+        """
+        To monitor effectivity and safety of complement on JHU subset,
+        we need to know what kind of complement was done for JHU subset
+        for each country (if country/countries specified) or for all countries.
+
+        Args:
+            country (str or list[str] or None): country/countries name or None (all countries)
+            province(str or None): province name
+            start_date(str or None): start date, like 22Jan2020
+            end_date(str or None): end date, like 01Feb2020
+            kwargs: keyword arguments of JHUDataComplementHandler(), control factors of complement
+
+        Raises:
+            ValueError: @province was specified when @country is not a string
+            covsirphy.SubsetNotFoundError: No records were registered for the area/dates
+
+        Returns:
+            pandas.DataFrame
+
+                Index
+                    reset index
+                Columns
+                    - country (str): country name
+                    - province (str): province name
+                    - Monotonic_confirmed (bool): True if applied for confirmed cases or False otherwise
+                    - Monotonic_fatal (bool): True if applied for fatal cases or False otherwise
+                    - Monotonic_recovered (bool): True if applied for recovered or False otherwise
+                    - Full_recovered (bool): True if applied for recovered or False otherwise
+                    - Partial_recovered (bool): True if applied for recovered or False otherwise
+        """
+        self._recovery_period = self._recovery_period or self.calculate_recovery_period()
+        # Area name
+        if country is None:
+            country = [
+                c for c in self._cleaned_df[self.COUNTRY].unique() if c != "Others"]
+        province = province or self.UNKNOWN
+        if not isinstance(country, str) and province != self.UNKNOWN:
+            raise ValueError(
+                "@province cannot be specified when @country is not a string.")
+        if not isinstance(country, list):
+            country = [country]
+        # Create complement handler
+        handler = JHUDataComplementHandler(
+            recovery_period=self._recovery_period, **kwargs)
+        # Check each country
+        complement_df = pd.DataFrame(
+            columns=[
+                self.COUNTRY, self.PROVINCE, *JHUDataComplementHandler.SHOW_COMPLEMENT_FULL_COLS])
+        complement_df.set_index(self.COUNTRY, inplace=True)
+        for cur_country in country:
+            subset_df = self._subset(
+                country=cur_country, province=province, start_date=start_date, end_date=end_date)
+            if subset_df.empty:
+                raise SubsetNotFoundError(
+                    country=cur_country, province=province, start_date=start_date, end_date=end_date)
+            *_, complement_dict = handler.run(subset_df)
+            complement_dict_values = pd.Series(
+                complement_dict.values(), dtype=bool).values
+            complement_df.loc[cur_country] = [
+                province, *complement_dict_values]
+        return complement_df.reset_index()
+
+    def map(self, country=None, variable="Confirmed", date=None,
+            included=None, excluded=None, filename=None, **kwargs):
+        """
+        Create global colored map to show the values.
+
+        Args:
+            country (str or None): country name or None (global map)
+            variable (str): variable name to show
+            date (str or None): date of the records or None (the last value)
+            included (list[str] or None): included countries/provinces or None (all)
+            excluded (list[str] or None): excluded countries/provinces or None (all)
+            filename (str or None): image filename or None (display)
+            kwargs: arguments of matplotlib.pyplot.savefig() and geopandas.GeoDataFrame.plot() except for 'column'
+
+        Note:
+            When @country is None, country level data will be shown on global map.
+            When @country is a country name, province level data will be shown on country map.
+        """
+        # Date
+        date_str = date or self.cleaned(
+        )[self.DATE].max().strftime(self.DATE_FORMAT)
+        country_str = country or "Global"
+        title = f"{country_str}: the number of {variable.lower()} cases on {date_str}"
+        # Global map
+        if country is None:
+            return self._colored_map_global(
+                variable=variable, title=title, date=date,
+                included=included, excluded=excluded, filename=filename, **kwargs)
+        # Country-specific map
+        return self._colored_map_country(
+            country=country, variable=variable, title=title, date=date,
+            included=included, excluded=excluded, filename=filename, **kwargs)
