@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 import pandas as pd
+from covsirphy.util.error import SubsetNotFoundError
 from covsirphy.cleaning.cbase import CleaningBase
 
 
@@ -52,9 +53,9 @@ class OxCGRTData(CleaningBase):
 
         Returns:
             pandas.DataFrame
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - Country (pandas.Category): country/region name
                     - ISO3 (str): ISO 3166-1 alpha-3, like JPN
@@ -76,12 +77,14 @@ class OxCGRTData(CleaningBase):
                 "Congo, the Democratic Republic of the": "Democratic Republic of the Congo",
                 # COG
                 "Congo": "Republic of the Congo",
+                # South Korea
+                "Korea, South": "South Korea",
                 # Diamond princess
                 "Diamond Princess": "Others",
             }
         )
         # Confirm the expected columns are in raw data
-        self.ensure_dataframe(
+        self._ensure_dataframe(
             df, name="the raw data", columns=self.OXCGRT_COLS
         )
         # Read date records
@@ -109,16 +112,24 @@ class OxCGRTData(CleaningBase):
             country (str): country name or ISO 3166-1 alpha-3, like JPN
             kwargs: the other arguments will be ignored in the latest version.
 
+        Raises:
+            covsirphy.SubsetNotFoundError: no records were found
+
         Returns:
             pandas.DataFrame
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - other column names are defined by OxCGRTData.COL_DICT
         """
+        country_arg = country
         country = self.ensure_country_name(country)
-        df = super().subset(country=country)
+        try:
+            df = super().subset(country=country)
+        except SubsetNotFoundError:
+            raise SubsetNotFoundError(
+                country=country_arg, country_alias=country) from None
         df = df.groupby(self.DATE).last().reset_index()
         return df.loc[:, self.OXCGRT_COLS_WITHOUT_COUNTRY]
 
