@@ -43,9 +43,9 @@ class PopulationData(CleaningBase):
 
         Returns:
             pandas.DataFrame
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - ISO3 (str): ISO3 code or "-"
                     - Country (pandas.Category): country/region name
                     - Province (pandas.Category): province/prefecture/state name
@@ -68,7 +68,7 @@ class PopulationData(CleaningBase):
         expected_cols = [
             self.COUNTRY, self.PROVINCE, self.N
         ]
-        self.ensure_dataframe(df, name="the raw data", columns=expected_cols)
+        self._ensure_dataframe(df, name="the raw data", columns=expected_cols)
         # ISO3
         df[self.ISO3] = df[self.ISO3] if self.ISO3 in df.columns else self.UNKNOWN
         # Date
@@ -80,6 +80,8 @@ class PopulationData(CleaningBase):
                 "Congo, the Democratic Republic of the": "Democratic Republic of the Congo",
                 # COG
                 "Congo": "Republic of the Congo",
+                # South Korea
+                "Korea, South": "South Korea",
             }
         )
         # Province
@@ -152,7 +154,7 @@ class PopulationData(CleaningBase):
         Returns:
             int: population in the place
 
-        Notes:
+        Note:
             If @date is None, the created date of the instancewill be used
         """
         country_alias = self.ensure_country_name(country)
@@ -178,11 +180,11 @@ class PopulationData(CleaningBase):
         Returns:
             covsirphy.PopulationData: self
 
-        Notes:
+        Note:
             If @date is None, the created date of the instance will be used.
             If @province is None, "-" will be used.
         """
-        population = self.ensure_natural_int(value, "value")
+        population = self._ensure_natural_int(value, "value")
         province = province or self.UNKNOWN
         date_stamp = pd.to_datetime(date or self._created_date())
         df = self._cleaned_df.copy()
@@ -212,7 +214,7 @@ class PopulationData(CleaningBase):
         Returns:
             list[str]: list of country names
 
-        Notes:
+        Note:
             Country 'Others' will be removed.
         """
         country_list = super().countries()
