@@ -60,7 +60,7 @@ class SEWIRF(ModelBase):
             - @sigma (float)
         """
         # Total population
-        self.population = self.ensure_natural_int(
+        self.population = self._ensure_natural_int(
             population, name="population"
         )
         # Non-dim parameters
@@ -105,9 +105,9 @@ class SEWIRF(ModelBase):
 
         Args:
             taufree_df (pandas.DataFrame):
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - t (int): time steps (tau-free)
                     - columns with dimensional variables
             population (int): total population
@@ -117,7 +117,7 @@ class SEWIRF(ModelBase):
                 - key (str): parameter name
                 - value (tuple(float, float)): min value and max value
         """
-        df = cls.ensure_dataframe(
+        df = cls._ensure_dataframe(
             taufree_df, name="taufree_df", columns=[cls.TS, *cls.VARIABLES]
         )
         df = df.loc[(df[cls.S] > 0) & (df[cls.CI] > 0)]
@@ -126,7 +126,8 @@ class SEWIRF(ModelBase):
         sigma_series = r.diff() / t.diff() / i
         # Calculate range
         _dict = {param: (0, 1) for param in cls.PARAMETERS}
-        _dict["sigma"] = tuple(sigma_series.quantile(cls.QUANTILE_RANGE).clip(0, 1))
+        _dict["sigma"] = tuple(sigma_series.quantile(
+            cls.QUANTILE_RANGE).clip(0, 1))
         return _dict
 
     @classmethod
@@ -136,9 +137,9 @@ class SEWIRF(ModelBase):
 
         Args:
             data_df (pandas.DataFrame):
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
                     - Fatal (int): the number of fatal cases
@@ -148,15 +149,15 @@ class SEWIRF(ModelBase):
 
         Returns:
             (pandas.DataFrame)
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - any columns @data_df has
                     - Susceptible (int): the number of susceptible cases
                     - Exposed (int): 0
                     - Waiting (int): 0
         """
-        df = cls.ensure_dataframe(
+        df = cls._ensure_dataframe(
             data_df, name="data_df", columns=cls.VALUE_COLUMNS)
         # Calculate dimensional variables
         df[cls.S] = population - df[cls.C]
@@ -173,9 +174,9 @@ class SEWIRF(ModelBase):
         Args:
             specialized_df (pandas.DataFrame): dataframe with the variables
 
-                Index:
+                Index
                     (object)
-                Columns:
+                Columns
                     - Susceptible (int): the number of susceptible cases
                     - Infected (int): the number of currently infected cases
                     - Recovered (int): the number of recovered cases
@@ -186,9 +187,9 @@ class SEWIRF(ModelBase):
 
         Returns:
             (pandas.DataFrame):
-                Index:
+                Index
                     (object): as-is
-                Columns:
+                Columns
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
                     - Fatal (int): the number of fatal cases
