@@ -44,7 +44,7 @@ class SIR(ModelBase):
 
     def __init__(self, population, rho, sigma):
         # Total population
-        self.population = self.ensure_natural_int(
+        self.population = self._ensure_natural_int(
             population, name="population"
         )
         # Non-dim parameters
@@ -77,9 +77,9 @@ class SIR(ModelBase):
 
         Args:
             taufree_df (pandas.DataFrame):
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - t (int): time steps (tau-free)
                     - columns with dimensional variables
             population (int): total population
@@ -89,7 +89,7 @@ class SIR(ModelBase):
                 - key (str): parameter name
                 - value (tuple(float, float)): min value and max value
         """
-        df = cls.ensure_dataframe(
+        df = cls._ensure_dataframe(
             taufree_df, name="taufree_df", columns=[cls.TS, *cls.VARIABLES]
         )
         df = df.loc[(df[cls.S] > 0) & (df[cls.CI] > 0)]
@@ -112,9 +112,9 @@ class SIR(ModelBase):
 
         Args:
             data_df (pandas.DataFrame):
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
                     - Fatal (int): the number of fatal cases
@@ -124,14 +124,14 @@ class SIR(ModelBase):
 
         Returns:
             (pandas.DataFrame):
-                    Index:
+                    Index
                         reset index
-                    Columns:
+                    Columns
                         - any columns @data_df has
                         - Susceptible (int): the number of susceptible cases
                         - Fatal or Recovered (int): total number of fatal/recovered cases
         """
-        df = cls.ensure_dataframe(
+        df = cls._ensure_dataframe(
             data_df, name="data_df", columns=cls.VALUE_COLUMNS)
         # Calculate dimensional variables
         df[cls.S] = population - df[cls.C]
@@ -147,9 +147,9 @@ class SIR(ModelBase):
         Args:
             specialized_df (pandas.DataFrame): dataframe with the variables
 
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Susceptible (int): the number of susceptible cases
                     - Infected (int): the number of currently infected cases
                     - Fatal or Recovered (int): the number of fatal/recovered cases
@@ -157,9 +157,9 @@ class SIR(ModelBase):
 
         Returns:
             (pandas.DataFrame):
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
                     - Fatal (int): the number of fatal cases
