@@ -49,7 +49,7 @@ class SIRF(ModelBase):
 
     def __init__(self, population, theta, kappa, rho, sigma):
         # Total population
-        self.population = self.ensure_natural_int(
+        self.population = self._ensure_natural_int(
             population, name="population"
         )
         # Non-dim parameters
@@ -86,9 +86,9 @@ class SIRF(ModelBase):
 
         Args:
             taufree_df (pandas.DataFrame):
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - t (int): time steps (tau-free)
                     - columns with dimensional variables
             population (int): total population
@@ -98,7 +98,7 @@ class SIRF(ModelBase):
                 - key (str): parameter name
                 - value (tuple(float, float)): min value and max value
         """
-        df = cls.ensure_dataframe(
+        df = cls._ensure_dataframe(
             taufree_df, name="taufree_df", columns=[cls.TS, *cls.VARIABLES]
         )
         df = df.loc[(df[cls.S] > 0) & (df[cls.CI] > 0)]
@@ -124,9 +124,9 @@ class SIRF(ModelBase):
 
         Args:
             data_df (pandas.DataFrame):
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
                     - Fatal (int): the number of fatal cases
@@ -136,13 +136,13 @@ class SIRF(ModelBase):
 
         Returns:
             (pandas.DataFrame)
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - any columns @data_df has
                     - Susceptible (int): the number of susceptible cases
         """
-        df = cls.ensure_dataframe(
+        df = cls._ensure_dataframe(
             data_df, name="data_df", columns=cls.VALUE_COLUMNS)
         # Calculate dimensional variables
         df[cls.S] = population - df[cls.C]
@@ -157,9 +157,9 @@ class SIRF(ModelBase):
         Args:
         specialized_df (pandas.DataFrame): dataframe with the variables
 
-            Index:
+            Index
                 (object)
-            Columns:
+            Columns
                 - Susceptible (int): the number of susceptible cases
                 - Infected (int): the number of currently infected cases
                 - Recovered (int): the number of recovered cases
@@ -168,9 +168,9 @@ class SIRF(ModelBase):
 
         Returns:
             (pandas.DataFrame)
-                Index:
+                Index
                     (object): as-is
-                Columns:
+                Columns
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
                     - Fatal (int): the number of fatal cases
