@@ -3,7 +3,7 @@
 
 import pandas as pd
 from covsirphy.util.error import UnExecutedError
-from covsirphy.cleaning.term import Term
+from covsirphy.util.term import Term
 from covsirphy.ode.mbase import ModelBase
 from covsirphy.simulation.estimator import Estimator
 from covsirphy.simulation.simulator import ODESimulator
@@ -59,10 +59,10 @@ class PhaseUnit(Term):
     """
 
     def __init__(self, start_date, end_date, population):
-        self.ensure_date_order(start_date, end_date, name="end_date")
+        self._ensure_date_order(start_date, end_date, name="end_date")
         self._start_date = start_date
         self._end_date = end_date
-        self._population = self.ensure_population(population)
+        self._population = self._ensure_population(population)
         # Summary of information
         self.info_dict = {
             self.START: start_date,
@@ -168,7 +168,7 @@ class PhaseUnit(Term):
         date = self.date_obj(date)
         return sta <= date <= end
 
-    @ property
+    @property
     def id_dict(self):
         """
         tuple(str): id_dict of the phase
@@ -229,28 +229,28 @@ class PhaseUnit(Term):
     def __bool__(self):
         return self._enabled
 
-    @ property
+    @property
     def start_date(self):
         """
         str: start date
         """
         return self._start_date
 
-    @ property
+    @property
     def end_date(self):
         """
         str: end date
         """
         return self._end_date
 
-    @ property
+    @property
     def population(self):
         """
         str: population value
         """
         return self._population
 
-    @ property
+    @property
     def tau(self):
         """
         int or None: tau value [min]
@@ -260,19 +260,19 @@ class PhaseUnit(Term):
     @ tau.setter
     def tau(self, value):
         if self._ode_dict[self.TAU] is None:
-            self._ode_dict[self.TAU] = self.ensure_tau(value)
+            self._ode_dict[self.TAU] = self._ensure_tau(value)
             return
         raise AttributeError(
             f"PhaseUnit.tau is not None ({self._ode_dict[self.TAU]}) and cannot be changed.")
 
-    @ property
+    @property
     def model(self):
         """
         covsirphy.ModelBase or None: model description
         """
         return self._model
 
-    @ property
+    @property
     def estimator(self):
         """
         covsirphy.Estimator or None: estimator object
@@ -311,9 +311,9 @@ class PhaseUnit(Term):
 
         Returns:
             pandas.DataFrame:
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Start: start date of the phase
                     - End: end date of the phase
                     - Population: population value of the start date
@@ -344,13 +344,13 @@ class PhaseUnit(Term):
             covsirphy.PhaseUnit: self
         """
         # Tau value
-        tau = self.ensure_tau(tau) or self._ode_dict[self.TAU]
+        tau = self._ensure_tau(tau) or self._ode_dict[self.TAU]
         # Model
         model = model or self._model
         if model is None:
             self._ode_dict[self.TAU] = tau
             return self
-        self._model = self.ensure_subclass(model, ModelBase, name="model")
+        self._model = self._ensure_subclass(model, ModelBase, name="model")
         self.info_dict[self.ODE] = model.NAME
         # Parameter values
         param_dict = self._ode_dict.copy()
@@ -370,13 +370,14 @@ class PhaseUnit(Term):
             self.day_param_dict = model_instance.calc_days_dict(tau)
         return self
 
-    @ property
+    @property
     def record_df(self):
         """
         pandas.DataFrame: records of the phase
-            Index:
+
+            Index
                 reset index
-            Columns:
+            Columns
                 - Date (pd.TimeStamp): Observation date
                 - Confirmed (int): the number of confirmed cases
                 - Infected (int): the number of currently infected cases
@@ -388,7 +389,7 @@ class PhaseUnit(Term):
 
     @ record_df.setter
     def record_df(self, df):
-        self._record_df = self.ensure_dataframe(
+        self._record_df = self._ensure_dataframe(
             df, name="df", columns=self.NLOC_COLUMNS)
         self.set_y0(df)
 
@@ -408,9 +409,9 @@ class PhaseUnit(Term):
 
         Args:
             record_df (pandas.DataFrame or None)
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
@@ -419,7 +420,7 @@ class PhaseUnit(Term):
                     - any other columns will be ignored
             **kwargs: keyword arguments of Estimator.run()
 
-        Notes:
+        Note:
             If @record_df is None, registered records will be used.
         """
         self._model_is_registered()
@@ -429,7 +430,7 @@ class PhaseUnit(Term):
         if record_df.empty:
             raise UnExecutedError(
                 "PhaseUnit.record_df = ...", message="or specify @record_df argument")
-        self.ensure_dataframe(
+        self._ensure_dataframe(
             record_df, name="record_df", columns=self.NLOC_COLUMNS)
         # Check dates
         sta = self.date_obj(self.start_date)
@@ -451,9 +452,9 @@ class PhaseUnit(Term):
         Args:
             estimator (covsirphy.Estimator): estimator which finished estimation
             record_df (pandas.DataFrame)
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
@@ -481,9 +482,9 @@ class PhaseUnit(Term):
 
         Args:
             record_df (pandas.DataFrame)
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
@@ -511,9 +512,9 @@ class PhaseUnit(Term):
 
         Returns:
             pandas.DataFrame
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - Confirmed (int): the number of confirmed cases
                     - Infected (int): the number of currently infected cases
@@ -521,7 +522,7 @@ class PhaseUnit(Term):
                     - Recovered (int): the number of recovered cases
                     - Variables of the model (int): Confirmed etc.
 
-        Notes:
+        Note:
             Simulation starts at the start date of the phase.
             Simulation end at the next date of the end date of the phase.
         """
