@@ -2,16 +2,12 @@
 # -*- coding: utf-8 -*-
 
 import functools
-import sys
 import warnings
-import matplotlib
-if not hasattr(sys, "ps1"):
-    matplotlib.use("Agg")
-import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 from scipy.optimize import curve_fit, OptimizeWarning
-from covsirphy.cleaning.term import Term
+from covsirphy.util.plotting import line_plot_multiple
+from covsirphy.util.term import Term
 
 
 class Trend(Term):
@@ -20,9 +16,9 @@ class Trend(Term):
 
     Args:
         sr_df (pandas.DataFrame)
-            Index:
+            Index
                 Date (pd.TimeStamp): Observation date
-            Columns:
+            Columns
                 - Recovered (int): the number of recovered cases (> 0)
                 - Susceptible (int): the number of susceptible cases
                 - any other columns will be ignored
@@ -32,7 +28,7 @@ class Trend(Term):
 
     def __init__(self, sr_df):
         # Dataset
-        self.sr_df = self.ensure_dataframe(
+        self.sr_df = self._ensure_dataframe(
             sr_df, name="sr_df", time_index=True, columns=[self.S, self.R])
         # Dataset for analysis
         if len(self.sr_df) < 3:
@@ -45,9 +41,10 @@ class Trend(Term):
     def result_df(self):
         """
         pandas.DataFrame: results of fitting
-            Index:
-                - index (Date) (pd.TimeStamp): Observation date
-            Columns:
+
+            Index
+                - Date (pandas.TimeStamp): Observation date
+            Columns
                 - Recovered: The number of recovered cases
                 - Susceptible_actual: Actual values of Susceptible
                 - columns defined by @columns
@@ -85,9 +82,9 @@ class Trend(Term):
 
         Returns:
             pandas.DataFrame: results of fitting
-                Index:
+                Index
                     - index (Date) (pd.TimeStamp): Observation date
-                Columns:
+                Columns
                     - Recovered: The number of recovered cases
                     - Susceptible_actual: Actual values of Susceptible
                     - columns defined by @columns
@@ -101,17 +98,17 @@ class Trend(Term):
 
         Args:
             sr_df (pandas.DataFrame): training dataset
-                Index:
+                Index
                     - index (Date) (pd.TimeStamp): Observation date
-                Columns:
+                Columns
                     - Recovered: The number of recovered cases
                     - Susceptible: Actual data of Susceptible
 
         Returns:
             pandas.DataFrame
-                Index:
+                Index
                     - index (Date) (pd.TimeStamp): Observation date
-                Columns:
+                Columns
                     - Recovered (int): The number of recovered cases
                     - Susceptible_actual (int): Actual values of Susceptible
                     - Susceptible_predicted (int): Predicted values of Susceptible
@@ -130,7 +127,7 @@ class Trend(Term):
             self.fit_fnc, x_series, y_series,
             p0=[a_ini, b_ini],
             # Increase mux number of iteration in curve fitting from 600 (default)
-            maxfev=5000
+            maxfev=10000
         )
         # Predict the values with the parameters
         f_partial = functools.partial(
@@ -145,7 +142,7 @@ class Trend(Term):
         Return the best RMSLE score.
 
         Returns:
-            (float): RMSLE score
+            float: RMSLE score
         """
         if self._result_df.empty:
             self.run()
@@ -157,15 +154,15 @@ class Trend(Term):
 
         Args:
             fit_df (pandas.DataFrame):
-                Index:
+                Index
                     - index (Date) (pd.TimeStamp): Observation date
-                Columns:
+                Columns
                     - Recovered (int): The number of recovered cases
                     - Susceptible_actual (int): Actual values of Susceptible
                     - Susceptible_predicted (int): Predicted values of Susceptible
 
         Returns:
-            (float): RMSLE score
+            float: RMSLE score
         """
         df = fit_df.replace(np.inf, 0)
         df = df.loc[df[f"{self.S}{self.A}"] > 0, :]
@@ -178,13 +175,13 @@ class Trend(Term):
         )
         return scores.sum()
 
-    def show(self, area, filename=None):
+    def show(self, area, **kwargs):
         """
         show the result as a figure.
 
         Args:
             area (str): area name
-            filename (str): filename of the figure, or None (display)
+            kwargs: keyword arguments of covsirphy.line_plot_multiple()
         """
         df = self._result_df.copy()
         df = df.rename({f"{self.S}{self.P}": "Predicted"}, axis=1)
@@ -194,91 +191,36 @@ class Trend(Term):
         # Plotting
         title = f"{area}: S-R trend from {start_date} to {end_date}"
         self.show_with_many(
-            result_df=df,
-            predicted_cols=["Predicted"],
-            title=title,
-            filename=filename
-        )
+            result_df=df, predicted_cols=["Predicted"], title=title, **kwargs)
 
     @classmethod
-    def show_with_many(cls, result_df, predicted_cols,
-                       title, vlines=None, filename=None):
+    def show_with_many(cls, result_df, predicted_cols, title, **kwargs):
         """
         show the result as a figure.
 
         Args:
             result_df (pandas.DataFrame): results of fitting
-                Index:
-                    - index (Date) (pd.TimeStamp): Observation date
-                Columns:
+
+                Index
+                    Date (pandas.TimeStamp): Observation date
+                Columns
                     - Recovered: The number of recovered cases
                     - Susceptible_actual: Actual values of Susceptible
                     - columns defined by @predicted_cols
             predicted_cols (list[str]): list of columns which have predicted values
             title (str): title of the figure
-            vlines (list[int]): list of Recovered values to show vertical lines
-            filename (str): filename of the figure, or None (show figure)
+            kwargs: keyword arguments of covsirphy.line_plot_multiple()
         """
-        result_df = cls.ensure_dataframe(
+        result_df = cls._ensure_dataframe(
             result_df, name="result_df", time_index=True,
             columns=[cls.R, f"{cls.S}{cls.A}", *predicted_cols]
         )
-        df = result_df.replace(np.inf, np.nan)
-        x_series = df[cls.R]
-        actual = df[f"{cls.S}{cls.A}"]
-        # Plot the actual values
-        warnings.simplefilter("ignore", FutureWarning)
-        plt.plot(
-            x_series, actual,
-            label="Actual", color="black",
-            marker=".", markeredgewidth=0, linewidth=0
-        )
-        # Plot the predicted values
-        for col in predicted_cols:
-            plt.plot(x_series, df[col], label=col.replace(cls.P, str()))
-        # x-axis
-        plt.xlabel(cls.R)
-        plt.xlim(0, None)
-        # y-axis
-        plt.ylabel(cls.S)
-        try:
-            plt.yscale("log", base=10)
-        except Exception:
-            plt.yscale("log", basey=10)
-        # Delete y-labels of log-scale (minor) axis
-        plt.setp(plt.gca().get_yticklabels(minor=True), visible=False)
-        plt.gca().tick_params(left=False, which="minor")
-        # Set new y-labels of major axis
-        ymin, ymax = plt.ylim()
-        ydiff_scale = int(np.log10(ymax - ymin))
-        yticks = np.linspace(
-            round(ymin, - ydiff_scale),
-            round(ymax, - ydiff_scale),
-            5,
-            dtype=np.int64
-        )
-        plt.gca().set_yticks(yticks)
-        fmt = matplotlib.ticker.ScalarFormatter(useOffset=False)
-        fmt.set_scientific(False)
-        plt.gca().yaxis.set_major_formatter(fmt)
-        # Title
-        plt.title(title)
-        # Vertical lines
-        if isinstance(vlines, (list, tuple)):
-            for value in vlines:
-                plt.axvline(x=value, color="black", linestyle=":")
-        # Legend
-        plt.legend(
-            bbox_to_anchor=(1.02, 0), loc="lower left", borderaxespad=0
-        )
-        # Save figure or show figure
-        warnings.simplefilter("ignore", UserWarning)
-        plt.tight_layout()
-        if filename is None:
-            plt.show()
-            return None
-        plt.savefig(
-            filename, bbox_inches="tight", transparent=False, dpi=300
-        )
-        plt.clf()
-        return None
+        result_df.rename(columns={f"{cls.S}{cls.A}": cls.ACTUAL}, inplace=True)
+        result_df.rename(columns=lambda x: x.replace(cls.P, ""), inplace=True)
+        predicted_cols = [
+            col.replace(cls.P, "") for col in predicted_cols]
+        # Line plotting
+        line_plot_multiple(
+            df=result_df.replace(np.inf, np.nan),
+            x_col=cls.R, actual_col=cls.ACTUAL, predicted_cols=predicted_cols,
+            title=title, ylabel=cls.S, y_logscale=True, **kwargs)
