@@ -6,7 +6,7 @@ import numpy as np
 import pandas as pd
 from scipy.integrate import solve_ivp
 from covsirphy.util.error import deprecate
-from covsirphy.cleaning.term import Term
+from covsirphy.util.term import Term
 from covsirphy.ode.mbase import ModelBase
 
 
@@ -55,9 +55,9 @@ class ODESimulator(Term):
                 "Simulation for two phases is not supported from version 2.7.0")
         # Register the setting
         self.setting = {
-            "model": self.ensure_subclass(model, ModelBase, name="model"),
-            self.STEP_N: self.ensure_natural_int(step_n, name="step_n"),
-            "population": self.ensure_population(population),
+            "model": self._ensure_subclass(model, ModelBase, name="model"),
+            self.STEP_N: self._ensure_natural_int(step_n, name="step_n"),
+            "population": self._ensure_population(population),
             ModelBase.PARAM_DICT: self._ensure_parameters(model, param_dict),
             self.Y0_DICT: self._ensure_initial_values(model, y0_dict),
         }
@@ -77,7 +77,7 @@ class ODESimulator(Term):
         Returns:
             dict(str, str): dictionary of parameters
 
-        Notes:
+        Note:
             If a parameter value is not registered, None will be registered.
         """
         param_dict = param_dict or {}
@@ -104,7 +104,7 @@ class ODESimulator(Term):
         Returns:
             dict(str, str): dictionary of initial values
 
-        Notes:
+        Note:
             If initial value of a variable is not registered, None will be registered.
         """
         y0_dict = y0_dict or {}
@@ -135,9 +135,9 @@ class ODESimulator(Term):
 
         Returns:
             (pandas.DataFrame):
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - t (int): Elapsed time divided by tau value [-]
                     - columns with dimensional variables
         """
@@ -172,9 +172,9 @@ class ODESimulator(Term):
 
         Returns:
             (pandas.DataFrame):
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - t (int): Elapsed time divided by tau value [-]
                     - columns with dimensionalized variables
         """
@@ -188,9 +188,9 @@ class ODESimulator(Term):
 
         Returns:
             (pandas.DataFrame):
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - t (int): Elapsed time divided by tau value [-]
                     - non-dimensionalized variables of Susceptible etc.
         """
@@ -212,9 +212,9 @@ class ODESimulator(Term):
 
         Returns:
             pandas.DataFrame
-                Index:
+                Index
                     reset index
-                Columns:
+                Columns
                     - Date (pd.TimeStamp): Observation date
                     - Country (str): country/region name
                     - Province (str): province/prefecture/state name
