@@ -50,7 +50,7 @@ class SubsetNotFoundError(KeyError, ValueError):
         self.message = "" if message is None else f" {message}"
 
     def __str__(self):
-        return f"Records{self.message} in {self.area}{self.date} were not found."
+        return f"No records{self.message} in {self.area}{self.date} were found."
 
     @staticmethod
     def _area(country, country_alias, province):
@@ -69,7 +69,7 @@ class SubsetNotFoundError(KeyError, ValueError):
             c_alias_str = ""
         else:
             c_alias_str = f" ({country_alias})"
-        province_str = "" if province is None else f"{province}, "
+        province_str = "" if province is None or province == "-" else f"{province}, "
         return f"{province_str}{country}{c_alias_str}"
 
     @staticmethod
@@ -155,3 +155,41 @@ class PCRIncorrectPreconditionError(KeyError):
         country_str = (" in country " + country) if not province else ""
         province_str = "" if province is None else (" in province " + province)
         return f"{province_str}{country_str}"
+
+
+class NotInteractiveError(ValueError):
+    """
+    Error when interactive shell is not used but forced to use it.
+
+    Args:
+        message (str or None): the other messages
+    """
+
+    def __init__(self, message=None):
+        self.message = "" if message is None else f" {message}"
+
+    def __str__(self):
+        return f"Interactive shell is not used.{self.message}"
+
+
+class UnExpectedValueError(ValueError):
+    """
+    Error when unexpected value was applied as the value of an argument.
+
+    Args:
+        name (str): argument name
+        value (object): value user applied
+        candidates (list[object]): candidates of the argument
+        message (str or None): the other messages
+    """
+
+    def __init__(self, name, value, candidates, message=None):
+        self.name = str(name)
+        self.value = str(value)
+        self.candidates_str = ", ".join(candidates)
+        self.message = "" if message is None else f" {message}"
+
+    def __str__(self):
+        s1 = f"@ {self.name} must be selected from '{self.candidates_str}',"
+        s2 = f"but {self.value} was applied.{self.message}"
+        return f"{s1} {s2}"
